@@ -182,9 +182,13 @@ class DgraphClient:
 
     def access_token_expired(self) -> bool:
         if self._access_jwt:
-            decoded = DecodedAccessToken.parse_obj(
-                jwt.decode(self._access_jwt, options={"verify_signature": False})
-            )
+            try:
+                decoded = DecodedAccessToken.parse_obj(
+                    jwt.decode(self._access_jwt, options={"verify_signature": False})
+                )
+            except jwt.ExpiredSignature:
+                print("Invalid Token, will refresh")
+                return True
             if decoded.exp < time.time() - 120:
                 print(f"token is about to expire at {decoded.exp=}")
                 return True
