@@ -731,7 +731,7 @@ def {edge_name}(self, _: Optional[{edge_resolver}] = None, /) -> {self.resolver_
         query_str = f"{self.node_name}QueryParams"
 
         resolver_header = f"""
-class {self.node_name}Resolver(Resolver):
+class {self.node_name}Resolver(Resolver[{self.node_name}]):
     node: ClassVar[Type[{self.node_name}]] = {self.node_name}
     edges: {edges_str} = Field(default_factory={edges_str})
     query_params: {query_str} = Field(default_factory={query_str}) 
