@@ -5,6 +5,8 @@ from pydantic import BaseModel
 from fastapi.encoders import jsonable_encoder
 from dgraph_orm import GQLException
 
+_NULL = "null-12345"
+
 
 class GQLInput(BaseModel):
     def to_gql_str(self) -> str:
@@ -29,7 +31,10 @@ class GQLInput(BaseModel):
                     s = f"{field_name}: {jsonable_encoder(val)}"
                     str_lst.append(s)
             else:
-                if isinstance(val, GQLInput):
+                if val == _NULL:
+                    s = f"{field_name}: null"
+                    str_lst.append(s)
+                elif isinstance(val, GQLInput):
                     val = val.to_gql_str()
                     s = f"{field_name}: {{ {val} }}"
                     str_lst.append(s)
